@@ -1794,10 +1794,7 @@ void reg_f3d<T>::UpdateControlPointPosition(T scale)
         T *gradientValuesX = static_cast<T *>(this->nodeBasedGradientImage->data);
         T *gradientValuesY = &gradientValuesX[nodeNumber];
 #ifdef _OPENMP
-#pragma omp parallel for default(none) \
-    shared(controlPointValuesX, controlPointValuesY, bestControlPointValuesX, \
-    bestControlPointValuesY, gradientValuesX, gradientValuesY, nodeNumber, scale, \
-    xOpt,yOpt) \
+#pragma omp parallel for default(shared) \
     private(i)
 #endif
         for(i=0; i<nodeNumber;i++){
@@ -1818,11 +1815,7 @@ void reg_f3d<T>::UpdateControlPointPosition(T scale)
         T *gradientValuesY = &gradientValuesX[nodeNumber];
         T *gradientValuesZ = &gradientValuesY[nodeNumber];
 #ifdef _OPENMP
-#pragma omp parallel for default(none) \
-    shared(controlPointValuesX, controlPointValuesY, controlPointValuesZ, \
-    bestControlPointValuesX, bestControlPointValuesY, bestControlPointValuesZ, \
-    gradientValuesX, gradientValuesY, gradientValuesZ, nodeNumber, scale, \
-    xOpt,yOpt,zOpt) \
+#pragma omp parallel for default(shared) \
     private(i)
 #endif
         for(i=0; i<nodeNumber;i++){
